Learn R Programming

demcon (version 0.4.0)

cow_index: CoW States Index

Description

Create an annual index of valid Correlates of War Nations States.

Usage

cow_index()

Arguments

Value

A data.frame of annual CoW states.

Details

This function generates a dataset to be used for indexing country-year datasets against the validated CoW states membership. In short, it will permit the user to quickly drop observations from country/territory-year data that although they are commonly included in a variety of political/geographical datasets, these nations or territories may be disputed (Palestine, Kosovo pre 2008), have a parent nation (Puerto Rico), or have other peculiarities that do not align with international standards (CoW, G&W, WDI, IMF).

This is built off of the states packages, which matched the official Correlates of War record at the time of publishing.

Examples

Run this code

cow_index<-demcon::cow_index()

Run the code above in your browser using DataLab