Learn R Programming

demcon (version 0.4.0)

p5_reg_cat: Code Polity Regime Classification

Description

Determine qualitative regime classifications based on Goldstone et al. (2010) Figure 1.

Usage

p5_reg_cat(exrec, parcomp, pretty = FALSE)

Value

A character vector of ordinal categorical regime classifications based on Goldstone et al. (2010).

Arguments

exrec

Executive Recruitment Concept (exrec) variable from raw Polity5 data.

parcomp

Competitive of Participation (parcomp) variable from raw Polity5 data.

pretty

Logical to format categories with no spaces and first letter capitalized.

Examples

Run this code
# \donttest{
polity<-demcon::get_polity5(write_out = FALSE)

polity$reg_cat<-demcon::p5_reg_cat(polity$exrec, polity$parcomp, pretty = TRUE)# }

Run the code above in your browser using DataLab