powered by
Determine qualitative regime classifications based on Goldstone et al. (2010) Figure 1.
p5_reg_cat(exrec, parcomp, pretty = FALSE)
A character vector of ordinal categorical regime classifications based on Goldstone et al. (2010).
Executive Recruitment Concept (exrec) variable from raw Polity5 data.
exrec
Competitive of Participation (parcomp) variable from raw Polity5 data.
parcomp
Logical to format categories with no spaces and first letter capitalized.
# \donttest{ polity<-demcon::get_polity5(write_out = FALSE) polity$reg_cat<-demcon::p5_reg_cat(polity$exrec, polity$parcomp, pretty = TRUE)# }
Run the code above in your browser using DataLab